*******************************************************************
* weapons.do
*******************************************************************
* Prepare data for "Detecting illegal arms trade" paper
*******************************************************************

clear
set mem 400m
set matsize 1000
set more off
cd "c:/Users/sdellavi/My Documents/Brief/Research/weapons/AEJDataPosting"
cap log close
log using regs/weapons, text replace

/*
*******************************************************************
*******************************************************************
* STEP 1. 	Infile stock price data, generate returns, and load additional stock variables
*& Corresponding to Section 3, Returns
*******************************************************************
*******************************************************************

**** STEP 1A. Load Stock Price Data and Compute Stock Returns **************
*& Notice: Data goes from 1984 to 2005, need 1984 to produce abnormal returns for 1985 -- 1984 dropped later
*& listing = country origin
*& li = market index price
*& mv = market cap
*& ri = price of stock, in local currency 
use regs/weaponsreturnsRaw, clear
label list
sort compname date

** !! DROP !! -- Drop market returns if series starts off at zero (Brazil)
ta compname listing if li<=.2
replace li=. if li<=.2
** !! DROP !! -- Penny stocks (less than $2)
ta compname listing if ri<2
replace ri=. if ri<=2

** Generate returns for the three series, including the market returns
*& Checking for stale markets/stocks
*& dstaleri, dstaleli, dstaleritemp, dstalelitemp, retri, retli created
foreach x in ri li {
	sort compname date
	gen dstale`x'=0
	gen dstale`x'temp=(`x'[_n]==`x'[_n-1] & `x'[_n-1]==`x'[_n-2] & `x'[_n-2]==`x'[_n-3] & `x'[_n-3]==`x'[_n-4] & /*
	*/ `x'[_n-4]==`x'[_n-5] & `x'[_n-5]==`x'[_n-6] & `x'[_n-6]==`x'[_n-7] & `x'[_n-7]==`x'[_n-8] & `x'[_n-8]==`x'[_n-9] & compname==compname[_n-9])
	sort compname date
	foreach n in 1 2 3 4 5 6 7 8 9 {
		replace dstale`x'=1 if (dstale`x'temp==1 | dstale`x'temp[_n+`n']==1) & compname==compname[_n+`n']
		}
	drop dstale`x'temp
	}
foreach x in ri li {
sort compname date
gen ret`x'=(`x'-`x'[_n-1])/`x'[_n-1] if compname==compname[_n-1]
label var ret`x' "Return computed from `x'"
** Set returns missing if stale
foreach w in "" {
	replace ret`w'`x'=. if dstale`x'==1
	}
}
**** Trim the top and bottom 2/10,000 of returns (outliers)
foreach x in retri {
	su `x',d
	xtile `x'pc=`x', nq(10000)
	ta year if `x'pc<=2 | (`x'pc>=9999 & `x'pc~=.)
	ta compname if `x'pc<=2 | (`x'pc>=9999 & `x'pc~=.)
	replace `x'=. if `x'pc<=2 | (`x'pc>=9999 & `x'pc~=.)
	su `x',d
	}
** Compute 3-day CAR returns
*& ret3ri, ret3li created
sort compname date
foreach x in ri li {
	gen ret3`x'=ret`x'+ret`x'[_n+1]+ret`x'[_n-1] if compname[_n+1]==compname[_n-2]
	label var ret3`x' "3-day return computed from `x'"
	}
** Drop unneeded variables
drop dstale* year ret*p* ri li ret3li

* Save file used for Table 6 on detection
compress
sort compname date
save regs/weapondataShortAEJ,replace



**** STEP 1B. Generate beta-corrected returns **************
*** Clean up data set
gen year=year(date)
egen compno=group(compname)
su compno
compress
memory
* 61m

*** Generate excess and abnormal returns -- takes a while -- 25 sec. per company now *& for 196 companies
* Skip a few companies because they drop out of the sample, no observations after 1987
*& eretri, aretri[1984-2004]temp created
foreach t in "" {
foreach r in ri {
gen eret`t'`r'=ret`t'`r'-ret`t'li
bys compno year: egen count=count(eret`t'`r')
gen aret`t'`r'=.
foreach y of numlist 1(1)196 {
	display `y'
foreach yr of numlist 1984(1)2004 {
	cap reg ret`t'`r' ret`t'li if compno==`y' & year==`yr' & count>=40
	cap predict aret`t'`r'`yr'temp if compno==`y' & year==`yr'+1, resid
	cap gen aret`t'`r'`yr'temp=.
	replace aret`t'`r'=aret`t'`r'`yr'temp if aret`t'`r'`yr'temp~=. & aret`t'`r'==. & year==`yr'+1
	drop aret`t'`r'`yr'temp
}
}
}
}	
*& Label vars
label var eretri "Excess returns"
label var aretri "Abnormal returns"
*&
* Generate 3-day returns
*& aret3ri created
foreach x in ri {
	sort compname date
	gen aret3`x'=aret`x'+aret`x'[_n+1]+aret`x'[_n-1] if compno[_n+1]==compno[_n-2]
	label var aret3`x' "3-day abnormal return computed from `x'"
	}

sort compname date
gen ret3li=retli+retli[_n+1]+retli[_n-1] if compno[_n+1]==compno[_n-2]
gen eret3ri=ret3ri-ret3li
*& Label vars
label var ret3li "3-day return computed from li"
label var eret3ri "3-day abnormal return computed from ri"
*&

drop year count compno
gen year=year(date)
sort compname year
compress
save regs/weaponsreturns, replace


** STEP 1C. **** Add data on market cap. and revenue in 1984 US$
** Merge to main weapon data
*& mvusd = market value in 1984, millions of dollars
*& revusd = revenue in 1984, millions of dollars
*& mvusdc and revusdc are more "complete" versions of mvusd and revusd

use regs/MktCapRevUSD,clear
sort compname year
merge compname year using regs/weaponsreturns
ta year _m, m
* _m==3 for all observations, except _m==1 for saab and verney and for year 1981-1983 and 2006
ta compname if year>=1984 & year<=2005 & _m==1
* verney and saab, plus dmix==1
ta compname if year>=1984 & year<=2005 & _m==2
* there is no SIPRI data (all missing) for ittinds rollsroyce sagem -- for aleniadm aleniapound generate from alenia
drop if _m==1
drop _m
sort compname date
** Compare the two series of market cap to complete the mvusd one which is not very complete
** The two series should be most similar at the end of December when the mvusd series is measured
gen day=day(date)
gen month=month(date)
foreach x in mvusd mvusdc revusd revusdc {
	replace `x'=. if retri==.
	}
ta listing if retri~=. & mvusd==.
ta listing if retri~=. & revusd==.
drop mv
** Companies with no observations for market cap. or revenue
ta compname if revusdc==. & retri~=.
ta compname if mvusdc==. & retri~=.
su *usdc,d
*& Label vars
label var mvusdc "Mvusd with values filled in"
label var revusdc "Revusd with values filled in" 
*&

** Generate dummies for size and market cap
gen dmvq1=(mvusdc<=78) if mvusdc~=.
gen drevq1=(revusdc<=146) if revusdc~=.

*& Label vars
label var dmvq1 "Dummy for market cap "
label var drevq1 "Dummy for revuene/size"
*&

compress
sort compname year date
save regs/weaponsreturns, replace
*/





*******************************************************************
*******************************************************************
* STEP 2. 	Infile data on various accessory data sets
* companydata -- data at company level ("Saab")
* compcountrydata -- data at company-country level ("Saab-Ethiopia")
* marketdata -- data at market level ("Sweden")
* marketyeardata -- data at market-year level ("Sweden-2003")
*******************************************************************
*******************************************************************

**** STEP 2A. Insheet company data on News Hits with Google
* Two measures -- emb ("embargo") and arms ("arms") -- are constructed as follows:
*        - Fraction of hits "Company + Word" / "Company" -- Fraction of company hits that are associated with arms trade in various ways
* The last measure, ctry, is specific to a specific country under embargo, though not specific to arms:
*        - Fraction of hits "Company + CountryName" / "Company" -- Fraction of company hits that are associated with a country
* All three measures require at least 100 hits in the denominator
* The measure for Ethiopia/Eritria is the average of Ethiopia and Eritria 
* Each of the measure was obtained by two groups of udnergradautes, labeled R and J -- we take the average 
*& hitsembJ, hitsembR, hitshgctryJ,  hitshgctryR, hitshgarmsJ, hitshgctryR, hitshgembJ, hitshgembR created
use regs/GoogleHitsRaw, clear

foreach y in "J" "R" {
	rename hitsembargo`y' hitsemb`y'
	foreach w in ctry arms emb {
		gen hitshg`w'`y'=hits`w'`y'/hitstot`y' if hitstot`y'>100
		replace hitshg`w'`y'=1 if hitshg`w'`y'>1 & hitshg`w'`y'~=.
		}
	}
*& hitshgctry, hitshgarms, hitshgemb created
foreach w in ctry arms emb {
	egen hitshg`w'=rmean(hitshg`w'J hitshg`w'R) if hitshg`w'J~=. | hitshg`w'R~=.
	}
egen hitstot=rmean(hitstotJ hitstotR) if hitstotJ~=. | hitstotR~=.
keep compname country hitshgctry hitshgarms hitshgemb hitstot
* Generate main measures
*& hitshgd90ctry, hitshgd90arms, hitshgd90emb created
foreach x in ctry arms emb {
	xtile hitshg`x'pc=hitshg`x', nq(100)
	gen byte hitshgd90`x'=(hitshg`x'pc>90) if hitshg`x'~=.
	drop hitshg`x'pc
	}
*&Label vars
label var hitshgd90ctry "top 10% in (company+countryname)/company query"
label var hitshgd90emb "top 10% in (company+embargo)/company query"
label var hitshgd90arms "top 10% in (company+arms)/company query"
*& 
drop hitshgarms hitshgemb hitshgctry hitstot
sort compname country
save regs/HitsGoogle, replace
** Save company-level data -- Have to get rid temporarily of the country aspect to this
keep if country=="Angola"
drop country hitsh*ctry
sort compname
merge compname using regs/compdata
ta _m
* Saab and verney have _m==2, else _m==3
drop _m
sort compname
save regs/companydata, replace

** Now generate a file with company-country structure
use regs/HitsGoogle, replace
keep compname country hits*ctry
sort compname country
save regs/compcountrydata, replace


****STEP 2B. Insheet files with market features

**** Transparency Barometer -- Small Arms Survey
** Load Data on transparency
* 2004 data
insheet using data/TranspIndex04.txt,clear
drop if transp==""
drop code
replace transp04=proper(trim(word(transp04,1)))
destring transp04, replace
replace country=proper(trim(country))
sort country
save regs/transpindex,replace
* 2005 data
insheet using data/TranspIndex05.txt,clear
drop if transp==.
replace country=proper(trim(country))
drop code
sort country
merge country using regs/transpindex
ta _m
drop _m
sort country
save regs/transpindex,replace
* 2006 data
insheet using data/TranspIndex06.txt,clear
drop if transp==.
replace country=proper(trim(country))
drop code
sort country
merge country using regs/transpindex
ta _m
drop _m
* Double-check sums
*& tot04, tot05, tot06, diff04, diff05, diff06 created
foreach x in "04" "05" "06" {
	egen tot`x'=rsum(access`x' clarity`x' compr`x' infodeliv`x' infolicensea`x' infolicenseb`x') if infolicenseb`x'~=.
	gen diff`x'=tot`x'-transp`x'
	}
replace diff06=diff06+timely06
list if (diff06>0 & diff06~=.) | (diff05>0 & diff05~=.) | (diff04>0 & diff04~=.)
* none
drop diff* tot*
* To guarantee comparability of criteria, rescale
replace transp06=(4/5)*transp06
*& transp created
foreach x in transp {
	egen `x'=rmean(`x'04 `x'05 `x'06) if `x'04~=.|`x'05~=.|`x'06~=.
	}
keep country transp
* Renormalize on unitary scale
replace transp=transp/20
* Turn so that high values are bad
foreach x in transp {
	replace `x'=1-`x'
	}
replace country=trim(proper(subinstr(country," ","",.)))
rename country market
label var transp "Overall transparency measure (out of 20) -- Small Arms Survey"
sort market
save regs/marketdata,replace


**** Insheet Shleifer measures of no self-dealing
insheet using data/ShleiferNoSelfDealing.txt,clear
keep market nodeal
label var nodeal "Measure of no self-dealing: From LaPorta et al. (2006)"
replace market=trim(proper(market))
* Turn so that high values are bad
replace nodeal=1-nodeal
sort market
merge market using regs/marketdata
ta market _m
drop _m 
sort market
save regs/marketdata,replace

**** Insheet measures of corruption of a country -- from OECD
insheet using data/CPI1995-1997.txt,clear
keep country cpi* year
rename cpi cpicur
reshape long cpi, i(country year) j(lag) string
drop if lag=="lag" & year==1997
replace year=1995 if year==1996 & lag=="lag"
drop lag 
sort country year 
save regs/CPI1995-1997, replace
insheet using data/CPI1998-2006.txt,clear
keep country cpi year
append using regs/CPI1995-1997
rename country market
* Renormalize to unitary scale
replace cpi=cpi/10
replace market=trim(proper(market))
replace market="Uk" if market=="Unit.Kingd."|market=="United Kingdom"
replace market="Usa" if market=="United States"
replace market="Czechrep" if market=="Czechrep."|market=="Czech Republic"
replace market="Southkorea" if market=="South Korea"
replace market="Southafrica" if market=="South Africa"
reshape wide cpi, i(market) j(year)
* Turn so that high values are bad
forvalues i=1995(1)2006 {
	replace cpi`i'=1-cpi`i'
	label var cpi`i' "Corruption Perception Index Year `i': From OECD"
	}
egen cpi=rmean(cpi*)
label var cpi "Corruption Perception Index Average: From OECD"
sort market 
merge market using regs/marketdata
ta market _m
drop _m 
sort market
save regs/marketdata,replace

**** Insheet measures of press freedom -- from 
insheet using data/PressFreedom94_2004.csv,clear names
foreach x in 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 {
	rename v`x' pressfr`x'
	destring pressfr`x', replace force
	replace pressfr`x'=pressfr`x'/100
	}
egen pressfr=rmean(pressfr*)
*& Label var
label var pressfr "Press Freedom Average across years"
rename country market
replace market=trim(proper(market))
replace market="Uk" if market=="Unit.Kingd."|market=="United Kingdom"
replace market="Usa" if market=="United States"
replace market="Czechrep" if market=="Czechrep."|market=="Czech Republic"
replace market="Southkorea" if market=="South Korea" | market=="Korea, South"
replace market="Southafrica" if market=="South Africa"
sort market 
merge market using regs/marketdata
ta market _m
drop _m
sort market
save regs/marketdata,replace

**** Insheet measure of Corruption from Kaufman et al. (2006)
insheet using data/CorrKaufman.txt, clear names
foreach x in 1996 1998 2000 2002 2003 2004 2005 {
	rename y`x' corrk`x'
	destring corrk`x', replace force
	replace corrk`x'=-corrk`x'
	}
egen corrk=rmean(corrk*)
*& Label var
label var corrk "Mean Kaufman corruption measure"
drop corrk1* corrk2*
rename country market
replace market=trim(proper(market))
replace market="Southkorea" if market=="South Korea" | market=="Korea, South"
replace market="Southafrica" if market=="South Africa"
replace market="Czechrep" if market=="Czechrep."|market=="Czech Republic"
replace market="Usa" if market=="United States"|market=="Us"
replace market="Uk" if market=="Unit.Kingd."|market=="United Kingdom"
sort market 
merge market using regs/marketdata
ta market _m
drop _m
sort market
save regs/marketdata,replace

**** Insheet measure of GDP
insheet using data/GDPUSD.txt, clear names
drop ctrycode
destring gdp, replace force
sort country year
replace gdp=gdp[_n-1] if year==2004 & gdp==.
gen lngdp=ln(gdp)
reshape wide gdp lngdp, i(country) j(year)
** Copy 2004 into 2005
gen gdp2005=gdp2004
gen lngdp2005=lngdp2004
rename country market
replace market=trim(proper(market))
replace market="Southkorea" if market=="South Korea" | market=="Korea, South" | market=="Korea, Republic Of"
replace market="Southafrica" if market=="South Africa"
replace market="Czechrep" if market=="Czechrep."|market=="Czech Republic"
replace market="Usa" if market=="United States"|market=="Us"
replace market="Uk" if market=="Unit.Kingd."|market=="United Kingdom"
sort market 
merge market using regs/marketdata
ta market _m
drop _m
sort market
save regs/marketdata,replace

**** Insheet measures of Bribe Payers Index from 2006 -- not comparable with previous series
use regs/BPI2006,clear
replace market=trim(proper(market))
replace market="Southkorea" if market=="South Korea" | market=="Korea, South"
replace market="Southafrica" if market=="South Africa"
replace market="Usa" if market=="United States"|market=="Us"
keep market bpi2006
rename bpi2006 bpi06
sort market 
merge market using regs/marketdata
ta market _m
drop _m
sort market
save regs/marketdata,replace

**** Insheet list of all countries to do median correctly
insheet using data/BPIdata.txt,clear names
replace market=trim(proper(market))
keep market
*** !!!! TAIWAN is only represented in NISAT, drop from list of countries Else will affect median !!! ***
drop if market=="Taiwan"
sort market 
merge market using regs/marketdata
ta market _m

** Measure of OECD country
gen samplenowest=(market~="Greece"&market~="Netherlands"&market~="Spain"&market~="Sweden"&market~="Uk"& market~="Usa"&market~="Australia"&market~="Belgium"&market~="Canada"&market~="France"&market~="Germany"& market~="Japan"&market~="Norway"&market~="Switzerland"&market~="Austria"&market~="Italy")
*gen samplenowest=(market~="Greece"&market~="Netherlands"&market~="Spain"&market~="Sweden"&market~="Uk"& /*
**/ market~="Usa"&market~="Australia"&market~="Belgium"&market~="Canada"&market~="France"&market~="Germany"& /*
**/ market~="Japan"&market~="Norway"&market~="Switzerland"&market~="Austria"&market~="Italy")
gen now=samplenowest

**** Now that all the market-level files are loaded, generate medians and standardize
* Eliminate if not in our final sample of markets -- the BPI data has the right list
drop if _m~=3
drop _m
*&  stbpi06, stpressfr, stcpi, stnodeal, sttransp, stcorrk 
*&  d2bpi06, d2pressfr, d2cpi, d2nodeal, d2transp, d2corrk created
foreach x in bpi06 pressfr cpi nodeal transp corrk {
	egen st`x'=std(`x')
	xtile `x'pc=`x', nq(2)
	gen byte d2`x'=(`x'pc==2) if `x'pc~=.
	}
*& label
label var d2cpi "Corruption Perception Index of countries in our sample"
label var d2transp  "Transparency Index of countries in our sample"
label var d2bpi06  "Bribepayer Index of countries in our sample"
drop *pc
*** Summarize data and do correlations
desc
pwcorr st*
pwcorr d2*
sort market
save regs/marketdata,replace

**** Generate a file that is country-level, and time-varying -- use only Log GDP
keep market lngdp*
reshape long lngdp, i(market) j(year)
sort market year
save regs/marketyeardata,replace

**** Eliminate the time-varying variable from the other measure
use regs/marketdata,replace
rename cpi cpiav
rename pressfr pressfrav
drop cpi1* cpi2* pressfr1* pressfr2* gdp* lngdp*
sort market
save regs/marketdata,replace
*/



*******************************************************************
*******************************************************************
* STEP 3. 	Read in data sets on embargoes and Merge with Returns Data
*******************************************************************
*******************************************************************

*** Sort the file on time zones -- we need it later
insheet using data/time_zones.txt,clear
drop v4
sort listing
save regs/time_zones, replace

** Open data on embargo events
use regs/eventsRaw,clear

* Generate measure of importance and unexpectedness of an event according to Lexis-Nexis
egen post=rmean(t10 t11)
egen pre=rmean(t9 t8 t7 t6)
gen unexplx=post/max(.25,pre)
gen implx=post
gen dunexp2=(unexplx>=2 & implx>=10)
gen dunexp3=(unexplx>=3 & implx>=20)
*& Label vars
label var post "Post event 2 day avg"
label var pre "Pre-event, 4 day avg"
label var unexplx "Surprise ratio"
*Don't know what mktemb is

gsort -unexplx
* List all events for embargo countries
sort country date
list country date implx unexplx unexpect dunexp* if (unexpect==1|unexpect==2) & mktemb==1 & (unembargo==1|unembargo==2)
* List all events that are ==2 during embargo
list country date implx unexplx unexpect dunexp* if (unexpect==2) & mktemb==1 & (unembargo==1|unembargo==2)
* List all events that are ==1 during embargo
list country date implx unexplx unexpect dunexp* if (unexpect==1) & mktemb==1 & (unembargo==1|unembargo==2)
list t* implx*  unexplx* if (unexpect==1|unexpect==2) & mktemb==1 & (unembargo==1|unembargo==2)
* List all events that are dunexp2==1 during embargo
list country date implx unexplx unexpect dunexp* if (dunexp2==1) & mktemb==1 & (unembargo==1|unembargo==2)
* List all events that are dunexp3==1 during embargo
list country date implx unexplx unexpect dunexp* if (dunexp3==1) & mktemb==1 & (unembargo==1|unembargo==2)
* List all events that are ==2 during embargo or outside embargo -- Appendix Table 1
list country date implx unexplx dunexp* unembargo if (unexpect==2) & mktemb==1, clean
ta unexpect dunexp2 if (unexpect==2|unexpect==1) & mktemb==1 & (unembargo==1|unembargo==2),m

gen byte events=0
replace events=1 if unexpe==2 & incr=="+" & mktemb==1
replace events=-1 if unexpe==2 & incr=="-" & mktemb==1
label var events "Very unexpected: 1 conflict increase, -1 conflict decrease"
gen byte events2=0
replace events2=1 if dunexp2==1 & incr=="+" & mktemb==1
replace events2=-1 if dunexp2==1 & incr=="-" & mktemb==1
label var events2 "Unexpected for Lexis-Nexis: 1 conflict increase, -1 conflict decrease"
gen byte events3=0
replace events3=1 if dunexp3==1 & incr=="+" & mktemb==1
replace events3=-1 if dunexp3==1 & incr=="-" & mktemb==1
label var events3 "Very unexpected for Lexis-Nexis: 1 conflict increase, -1 conflict decrease"
gen byte eventl=0
replace eventl=1 if (unexpe==1|unexpe==2) & incr=="+" & mktemb==1
replace eventl=-1 if (unexpe==1|unexpe==2) & incr=="-" & mktemb==1
label var eventl "Mildly or very unexpected: 1 conflict increase, -1 conflict decrease"
gen byte eventsne=0
replace eventsne=1 if unexpe==2 & incr=="+" & mktemb==0
replace eventsne=-1 if unexpe==2 & incr=="-" & mktemb==0
label var eventsne "Very unexpected in country with no embargo: 1 conflict increase, -1 conflict decrease"
replace descr=substr(descr,1,40)

** Make sure there is only one event on each date
* Make change just for sorting purposes
replace unexpe=20 if unexpe==2
sort date unexpe
list if date==date[_n+1]|date==date[_n-1]
drop if date==date[_n+1]

** Drop unnecessary variables
drop incr eventtype t* post* pre* dunexp*
sort country date

** Input time zone data
rename country listing
merge listing using regs/time_zones
ta _m
* no _m==1
drop if _m==2
drop _m listingno
rename listing country
rename time timecountry
compress
sort date
save regs/events, replace


** Re-sort file that we need later
use regs/time_zones, clear
sort listingno
save regs/time_zones, replace


**** STEP 3B. Do merge of stock data and events data
clear
set mem 700m
use regs/events, clear
duplicates list date
* Expand by number of markets in which companies are traded -- currently, 29
expand 29
sort date
gen listingno=1
replace listingno=listingno[_n-1]+1 if date==date[_n-1]
sort listingno date
merge listingno using regs/time_zones
ta _m
* _m==2 for the countries like Liberia, Sierra Leone
drop if _m==2
drop _m
drop listingno
rename time timemarket
gen timediff=timemarket-timecountry
*** Rule to shift the date -- We used to do this ad hoc (ASIA / NON ASIA), now fixed
* !!!!!!!!!!! THRESHOLD FOR SHIFTING !!!!!!!!!!!!!!
replace date=date+1 if timediff>15
replace date=date-1 if timediff<-15
drop time*

** Correction for weekend
gen weekday=dow(date)
replace date=date+2 if weekday==6
replace date=date+1 if weekday==0
gen weekday2=dow(date)
* Avoid two events on same date -- have to repeat this, since we shifted events on the weekend
sort listing date unexpected
list if (listing==listing[_n+1]&date==date[_n+1])|(date==date[_n-1]&listing==listing[_n-1])
drop if listing==listing[_n+1]&date==date[_n+1]
drop weekday2 unexpected
rename weekday weekdayevent
sort listing date
save regs/events, replace

use regs/weaponsreturns, clear
sort listing date
merge listing date using regs/events
ta _m
drop if _m==2
drop weekdayevent _m


**** STEP 3C. Add lags and leads to compute placebos, Generate main variables and drop unused observations
**** !!!!!! DROP !!!!!!
drop if year<=1984
foreach x in events events2 events3 eventsne eventl unexplx implx {
	recode `x' .=0
	}
*& events, events2, events3, eventsl, eventsne
*& evsemb, evs2emb, evs3emb, evslemb, evsneemb
*& evsnoemb, evs2noemb, evs3noemb, evslnoemb, evsnenoemb created
foreach x in s s2 s3 l sne {
	rename event`x' ev`x'
	gen byte ev`x'emb=ev`x'*(unembargo==1|unembargo==2)
	gen byte ev`x'noemb=ev`x'*(unembargo==0|unembargo==.)
	}
label var evsemb "Strict: Event during UN or EU embargo"
label var evlemb "Large: Event during UN or EU embargo"
label var evsnoemb "Strict: Event *not* during UN or EU embargo"
label var evlnoemb "Large: Event *not* during UN or EU embargo"
** Leads and lags of events variable and of return variables
sort compname date
*& evsembm[1-200], evsembp[1-200] created
forvalues n=1/200 {
	gen byte evsembm`n'=evsemb[_n-`n'] if compname==compname[_n-`n']
	gen byte evsembp`n'=evsemb[_n+`n'] if compname==compname[_n+`n']
*& label vars
	label var evsembm`n' "Indicator for whether evsemb matches `n' days in the past"  
	label var evsembp`n' "Indicator for whether evsemb matches `n' days in the future"  
*&
	}
sort compname date
gen aret2ri=aretri+aretri[_n+1] if compname==compname[_n+1]
gen aretrim1=aretri[_n-1] if compname==compname[_n-1]
gen aretrim2=aretri[_n-2] if compname==compname[_n-2]
gen aretrip1=aretri[_n+1] if compname==compname[_n+1]
gen aretrip2=aretri[_n+2] if compname==compname[_n+2]

*** Variable for any year-company observation with more than 30 trading days missing
* due to either stale trading days or missing data
bys compname year: egen stalecompyr=count(retri)
gen byte dstalecompyr=(stalecompyr<230)
count if retri~=. & dstalecompyr==1
count if retri~=. & dstalecompyr==0
drop stalecompyr
 
**** !!!!!! DROP !!!!!! -- do not do before in order to keep correct lags
drop if retri==. | aretri==.
drop mktemb
compress




*******************************************************************
*******************************************************************
* STEP 4. 	Do merges of secondary data sets
*******************************************************************
*******************************************************************

**** STEP 4A. ** Merge with company, country, marketcountry, and marketyear data
sort compname
merge compname using regs/companydata
ta _m
ta compname _m if _m~=3
* _m==2 for companies that we dropped because duplicates, saab and verney, for SIPRI, and companies with no data
drop if _m==2
drop _m
compress 
sort compname country
merge compname country using regs/compcountrydata
ta _m
ta compname _m if _m~=3
ta country _m if _m~=3
drop if _m==2
drop _m
compress
sort market
merge market using regs/marketdata
ta market _m, m
* All _m==3 after the change
drop if _m==2
drop _m
compress
sort market year
merge market year using regs/marketyeardata
ta market _m,m
ta year _m,m
drop if _m==2
drop _m


**** STEP 4B. ** Generate needed interactions
* Generate interactions for benchmark variables

*& evsembd2cpi, evsembd2transp
*& evs2embd2cpi, evs2embd2transp
*& evs3embd2cpi, evs3embd2transp
*& evlembd2cpi, evlembd2transp
*& evsneembd2cpi, evsneembd2transp created
foreach x in s s2 s3 l sne {
	foreach y in d2cpi d2transp {
		gen byte ev`x'emb`y'=ev`x'emb*`y'
		}
	}
*& labelling
label var evsembd2cpi "Interaction term with corrupt countries"

* Generate interactions for non-benchmark variables -- Do separately continuous and discrete variables
gen byte d2nocpi=(d2cpi==0) if d2cpi~=.
*& evsnoembd2cpi, evsnoembd2transp, evsnenoembd2cpi, evsnenoembd2transp
*& evsembd2pressfr, evsembd2bpi06, evsembd2nodeal, evsembd2corrk, evsembd2nocpi, evsembdrevq1
*& evsembstcpi, evsembsttransp, evsembstpressfr, evsembstbpi06, evsembstnodeal, evsembstcorrk, evsemblngdp created
foreach x in s {
	foreach y in d2cpi d2transp {
		gen byte ev`x'noemb`y'=ev`x'noemb*`y'
		gen byte ev`x'nenoemb`y'=ev`x'nenoemb*`y'
		}
	foreach y in now d2pressfr d2bpi06 d2nodeal d2corrk d2nocpi drevq1 {
		gen byte ev`x'emb`y'=ev`x'emb*`y'
		}
	foreach y in stcpi sttransp stpressfr stbpi06 stnodeal stcorrk lngdp {
		gen ev`x'emb`y'=ev`x'emb*`y'
		}
	}

*& labelling
label var evsembd2nocpi "Interaction term with non-corrupt countries"
label var evsemblngdp "Interaction term with ln gdp"

**** STEP 4C. Generate sample for regressions and save
gen sample1=((dwscope==1|dsipri==1) & aret3ri~=.)
keep if sample1==1
label var sample1 "3 day abnormal returns is calculated & makes weapons"  
sort compname date
compress
drop dmix
save regs/weaponsregsAEJ, replace
